@@ -24,7 +24,7 @@ from mcp.server.models import (
     ServerCapabilities,
 )
 from mcp.server.stdio import stdio_server
-from mcp import (
+from mcp.types import (
     Tool,
     ListToolsResult,
     ListResourcesResult,
@@ -83,7 +83,7 @@ class ConstituteServer:
             Tool(
                 name="get_constitutions_list",
                 description="Get a list of all available constitutions",
-                input_schema={
+                inputSchema={
                     "type": "object",
                     "properties": {
                         "show_details": {
@@ -101,7 +101,7 @@ class ConstituteServer:
             Tool(
                 name="find_constitution_by_country",
                 description="Find constitutions by country name",
-                input_schema={
+                inputSchema={
                     "type": "object",
                     "properties": {
                         "country_name": {
@@ -120,7 +120,7 @@ class ConstituteServer:
             Tool(
                 name="scrape_constitution",
                 description="Scrape the full content of a specific constitution",
-                input_schema={
+                inputSchema={
                     "type": "object",
                     "properties": {
                         "constitution_id": {
@@ -135,7 +135,7 @@ class ConstituteServer:
             Tool(
                 name="get_article_by_number",
                 description="Get a specific article from a constitution by its number",
-                input_schema={
+                inputSchema={
                     "type": "object",
                     "properties": {
                         "constitution_id": {
@@ -154,7 +154,7 @@ class ConstituteServer:
             Tool(
                 name="get_articles_range",
                 description="Get a range of articles from a constitution",
-                input_schema={
+                inputSchema={
                     "type": "object",
                     "properties": {
                         "constitution_id": {
@@ -177,7 +177,7 @@ class ConstituteServer:
             Tool(
                 name="search_articles_by_keyword",
                 description="Search for articles containing specific keywords",
-                input_schema={
+                inputSchema={
                     "type": "object",
                     "properties": {
                         "constitution_id": {
@@ -196,7 +196,7 @@ class ConstituteServer:
             Tool(
                 name="topic_constitutions",
                 description="Find constitutions by topic key",
-                input_schema={
+                inputSchema={
                     "type": "object",
                     "properties": {
                         "topic_key": {
@@ -227,7 +227,7 @@ class ConstituteServer:
             Tool(
                 name="topic_sections",
                 description="Get specific sections from a constitution related to a topic",
-                input_schema={
+                inputSchema={
                     "type": "object",
                     "properties": {
                         "topic_key": {"type": "string", "description": "Topic key to search for"},
@@ -256,7 +256,7 @@ class ConstituteServer:
             Tool(
                 name="export_constitution_json",
                 description="Export constitution data as JSON",
-                input_schema={
+                inputSchema={
                     "type": "object",
                     "properties": {
                         "constitution_id": {"type": "string", "description": "ID of the constitution"},
@@ -269,7 +269,7 @@ class ConstituteServer:
             Tool(
                 name="export_constitution_text",
                 description="Export constitution as plain text",
-                input_schema={
+                inputSchema={
                     "type": "object",
                     "properties": {
                         "constitution_id": {"type": "string", "description": "ID of the constitution"},
@@ -282,7 +282,7 @@ class ConstituteServer:
             Tool(
                 name="scrape_all_constitutions",
                 description="Scrape all available constitutions (batch operation)",
-                input_schema={
+                inputSchema={
                     "type": "object",
                     "properties": {
                         "limit": {"type": "integer", "description": "Limit the number of constitutions"},
@@ -559,7 +559,7 @@ async def main() -> None:
             write_stream,
             InitializationOptions(
                 server_name="constitute-mcp",
-                server_version="0.1.17",
+                server_version="0.1.24",
                 capabilities=ServerCapabilities(
                     tools={"listChanged": True},
                     prompts={"listChanged": False},
